OC.L10N.register(
    "groupfolders",
    {
    "Deny" : "inkär et",
    "Allow" : "Rugsat ber",
    "Create" : "Dörediň",
    "Delete" : "Pozmak",
    "Share" : "Paýlaş",
    "Default" : "Bellenen",
    "Folder name" : "Papkanyň ady",
    "User" : "Ulanyjy",
    "Unknown" : "Näbelli",
    "None" : "Hiç",
    "{size} used" : "{size}ulanyldy",
    "Unset" : "Gurnalmady"
},
"nplurals=2; plural=(n != 1);");
